#
# spec file for package bcunit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libbcunit
%define sover   1
Name:           bcunit
Version:        3.0.2+git.20191119
Release:        bp156.3.4
Summary:        Provide C programmers basic testing functionality
License:        LGPL-2.0-or-later
URL:            https://linphone.org/
Source:         %{name}-%{version}.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE bcunit-link-ncurses.patch jengelh@medozas.de
Patch0:         bcunit-link-ncurses.patch
# PATCH-FIX-OPENSUSE bcunit-ncurses6.patch idonmez@suse.com -- Compile with ncurses6.
Patch1:         bcunit-ncurses6.patch
# PATCH-FIX-OPENSUSE bcunit-sover.patch sor.alexei@meowr.ru -- Correctly set the sover.
Patch2:         bcunit-sover.patch
BuildRequires:  cmake
BuildRequires:  git-core >= 1.7.10
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
BCUnit is a unit testing framework for C, derived from CUnit.
(B)CUnit provides various interfaces to the framework, some of which
are platform dependent (e.g. curses on *nix). The framework complies
with the conventional structure of test cases bundled into suites
which are registered with the framework for running.

%package devel
Summary:        BCUnit development files
Requires:       %{soname}%{sover} = %{version}
Requires:       ncurses-devel
Recommends:     %{name}-doc = %{version}

%description devel
BCUnit is a unit testing framework for C.
This package installs the BCUnit development files.

%package doc
Summary:        BCUnit documentation
Requires:       %{soname}%{sover} = %{version}

%description doc
BCUnit is a unit testing framework for C.
This package installs the BCUnit documentation files.

%package -n %{soname}%{sover}
Summary:        BCUnit shared library

%description  -n %{soname}%{sover}
BCUnit is a unit testing framework for C.
This package installs the BCUnit shared library.

%prep
%autosetup -p1

%build
%cmake \
  -DENABLE_STATIC=OFF    \
  -DENABLE_DOC=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_libdir}/BCUnit/

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%doc AUTHORS ChangeLog NEWS README.md TODO
%license COPYING
%{_libdir}/%{soname}.so.%{sover}*

%files doc
%dir %{_datadir}/BCUnit/
%dir %{_datadir}/doc/BCUnit/
%doc %{_datadir}/doc/BCUnit/*
%doc %{_datadir}/BCUnit/*
%{_mandir}/man3/BCUnit.3%{?ext_man}

%files devel
%{_includedir}/BCUnit/
%dir %{_datadir}/BCunit/
%{_libdir}/BCUnit/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/bcunit.pc
%{_datadir}/BCunit/cmake/

%changelog
* Thu Feb 27 2020 Paolo Stivanin <info@paolostivanin.com>
- use correct archive extensione (xz instead of gz)
* Thu Feb 27 2020 Martin Pluskal <mpluskal@suse.com>
- Small packaging cleanups
* Wed Feb 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to latest master. This is needed for us in order to be able to
  update bctoolbox, ortp and bzrtp to the latest version
- Update bcunit-sover.patch accordingly
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 3.0.2:
  * Version bump.
* Tue Jun 13 2017 jengelh@inai.de
- Rewrite incorrect %%description of main RPM.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 3.0+git20170404:
  * No changelog available.
- Rename the package to bcunit for the fork.
- Rename and rebase cunit-link-ncurses.dif to
  bcunit-link-ncurses.patch,
  cunit-ncurses6.patch to bcunit-ncurses6.patch.
- Switch to cmake.
- Add bcunit-sover.patch: Correctly set the sover.
- Disable test: doesn't compile correctly.
- Correct the licence to LGPL-2.0+ (nothing limits to LGPL-2.0).
- Add baselibs.conf.
- Minor spec clean up.
* Thu Oct 22 2015 idonmez@suse.com
- Add cunit-ncurses6.patch to compile with ncurses6
* Tue May 26 2015 ddiss@suse.com
- Don't tag Recommends on RHEL, it yields an "Unknown tag" error.
* Tue Aug 12 2014 tchvatal@suse.com
- Use proper group for the library.
* Mon Aug  4 2014 tchvatal@suse.com
- The license is actually LGPL
* Mon Aug  4 2014 tchvatal@suse.com
- Update to release 2.1.3:
  * prune the static-devel subpackage as it is pointless.
  * Various upstream fixes with no changelog.
- Cleanup with spec-cleaner to have the spec pretty
* Thu Feb  9 2012 jengelh@medozas.de
- Update to new upstream release 2.1.2
  * modified dtd and xsl files to support inactive suites/tests
  * Added ability to deactivate suite/tests dynamically
  * Removed constraint that suite/test names be unique
- Remove redundant tags/sections
- Parallel build with %%_smp_mflags
- Add autotools BuildRequires for factory/12.2
- Fix use of implicitly defined function in source
  (do not declare that post-build-checks's output was wrong)
- Add missing DT_NEEDED entry on ncurses
* Tue Jun  8 2010 andrea@opensuse.org
- fixed 'no-pkg-config-provides'
* Wed Apr 21 2010 prusnak@suse.cz
- cleaned up spec, split devel-static subpackage
* Sat Mar 13 2010 andrea@opensuse.org
- added CUnit-2.1-pkgconfig.patch to provide cunit.pc
* Wed Mar  3 2010 andrea@opensuse.org
- split into 3 subpackages
* Tue Mar  2 2010 andrea@opensuse.org
- New package
